![CI](https://github.com/tellor-io/pytelliot/actions/workflows/py38.yml/badge.svg)
![Docs](https://github.com/tellor-io/pytelliot/actions/workflows/docs.yml/badge.svg)
[![codecov](https://codecov.io/gh/tellor-io/pytelliot/branch/main/graph/badge.svg?token=S1199HQ2EK)](https://codecov.io/gh/tellor-io/pytelliot)
[![Discord Chat](https://img.shields.io/discord/461602746336935936)](https://discord.com/invite/n7drGjh)
[![Twitter Follow](https://img.shields.io/twitter/follow/wearetellor?style=social)](https://twitter.com/WeAreTellor)

# Telliot Core

Telliot is a Python framework for interacting with the decentralized TellorX network.
This `telliot-core` repo contains the telliot core functionality and plugin framework
for use by other telliot packages and data feeds.

Please refer to the following for additional information:

- [Telliot Core Documentation](https://tellor-io.github.io/telliot-core/)
- [TellorX Whitepaper](https://www.tellor.io/static/media/tellorX-whitepaper.f6527d55.pdf)

This package should only be installed by advanced users, contributors, and developers of
custom data feeds.  For more information on contributing and setting up a development environment, please
[check here](https://tellor-io.github.io/telliot-core/contributing/)

To become a Tellor reporter, begin by installing the
[telliot-feed-examples](https://github.com/tellor-io/telliot-feed-examples) package.
